Index: sandbox/win/src/sandbox_types.h |
=================================================================== |
--- sandbox/win/src/sandbox_types.h (revision 155197) |
+++ sandbox/win/src/sandbox_types.h (working copy) |
@@ -54,7 +54,8 @@ |
SBOX_FATAL_DROPTOKEN = 7007, // Could not lower the token. |
SBOX_FATAL_FLUSHANDLES = 7008, // Failed to flush registry handles. |
SBOX_FATAL_CACHEDISABLE = 7009, // Failed to forbid HCKU caching. |
- SBOX_FATAL_CLOSEHANDLES = 7010 // Failed to close pending handles. |
+ SBOX_FATAL_CLOSEHANDLES = 7010, // Failed to close pending handles. |
+ SBOX_FATAL_MITIGATION = 7011 // Could not set the mitigation policy. |
}; |
class BrokerServices; |